/*****************************************************************************
*
*	File		SAZConfiguration.java
*	Author		Valery Sergeev, Neha Sharma
*	Date		Tue Sept 22 10:29:15 CDT 2009
*	Organization	Fermi National Accelerator Laboratory
*	Description	To get the default SAZ Server Configuration
*	Email		neha@fnal.gov
*
*
******************************************************************************/

package gov.fnal.vox.saz.bl.util;

import java.io.IOException;
import java.util.Vector;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;
import org.apache.log4j.Logger;
 
public class SAZConfiguration{	
	private int numberOfElements;
	private Document dom;
	private static SAZConfiguration ref;
	private static final transient Logger logger=Logger.getLogger(SAZConfiguration.class.getName());
	private String SAZ_USER_TRUSTED;
	private String SAZ_USER_ENABLED;
	private String SAZ_CA_TRUSTED;
	private String SAZ_CA_ENABLED;
	private String SAZ_VO_TRUSTED;
	private String SAZ_VO_ENABLED;
	private String SAZ_ROLE_TRUSTED;
	private String SAZ_ROLE_ENABLED;
	private String SAZ_BAN_USERCERT_SERIALNUM;
	private String SAZ_BAN_USERPROXY_LIFETIME;
	private String USERPROXY_LIFETIME;
	
	private SAZConfiguration(String fileName){
		parseSAZConfFile(fileName);
	}
	public static synchronized SAZConfiguration getInstance(String fileName){
		if(ref==null){
			ref=new SAZConfiguration(fileName);
		}
		return ref;
	}
	public static synchronized SAZConfiguration getInstance(){
		return ref;
	}		
	private void parseSAZConfFile(String fileName){
		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		try{
			//Using factory get an instance of document builder
			DocumentBuilder db = dbf.newDocumentBuilder();
			//parse using builder to get DOM representation of the XML file
			dom = db.parse(fileName);
			System.out.println("XML File = "+fileName);
		}catch(ParserConfigurationException pce){
			pce.printStackTrace();
		}catch(SAXException se){
			se.printStackTrace();
		}catch(IOException ioe){
			ioe.printStackTrace();
		}
		setDefaultSAZConfValues();
	}
	private void setDefaultSAZConfValues(){
		Element docEle = dom.getDocumentElement();
		NodeList nl = docEle.getElementsByTagName("SAZ_USER_TRUSTED");
		Element el = (Element)nl.item(0);					
		SAZ_USER_TRUSTED=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("SAZ_USER_ENABLED");
		el = (Element)nl.item(0);			
		SAZ_USER_ENABLED=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("SAZ_CA_TRUSTED");
		el = (Element)nl.item(0);			
		SAZ_CA_TRUSTED=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("SAZ_CA_ENABLED");
		el = (Element)nl.item(0);			
		SAZ_CA_ENABLED=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("SAZ_VO_TRUSTED");
		el = (Element)nl.item(0);			
		SAZ_VO_TRUSTED=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("SAZ_VO_ENABLED");
		el = (Element)nl.item(0);			
		SAZ_VO_ENABLED=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("SAZ_ROLE_TRUSTED");
		el = (Element)nl.item(0);			
		SAZ_ROLE_TRUSTED=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("SAZ_ROLE_ENABLED");
		el = (Element)nl.item(0);			
		SAZ_ROLE_ENABLED=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("SAZ_BAN_USERCERT_SERIALNUM");
		el = (Element)nl.item(0);
		SAZ_BAN_USERCERT_SERIALNUM=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("SAZ_BAN_USERPROXY_LIFETIME");
                el = (Element)nl.item(0);
                SAZ_BAN_USERPROXY_LIFETIME=el.getLastChild().getNodeValue();
		nl = docEle.getElementsByTagName("USERPROXY_LIFETIME");
                el = (Element)nl.item(0);
                USERPROXY_LIFETIME=el.getLastChild().getNodeValue();
		System.out.println("SAZ_USER_TRUSTED = "+SAZ_USER_TRUSTED);
		System.out.println("SAZ_USER_ENABLED = "+SAZ_USER_ENABLED);
		System.out.println("SAZ_CA_TRUSTED = "+SAZ_CA_TRUSTED);
		System.out.println("SAZ_CA_ENABLED = "+SAZ_CA_ENABLED);
		System.out.println("SAZ_VO_TRUSTED = "+SAZ_VO_TRUSTED);
		System.out.println("SAZ_VO_ENABLED = "+SAZ_VO_ENABLED);
		System.out.println("SAZ_ROLE_TRUSTED = "+SAZ_ROLE_TRUSTED);
		System.out.println("SAZ_ROLE_ENABLED = "+SAZ_ROLE_ENABLED);
		System.out.println("SAZ_BAN_USERCERT_SERIALNUM = "+SAZ_BAN_USERCERT_SERIALNUM);
		System.out.println("SAZ_BAN_USERPROXY_LIFETIME = "+SAZ_BAN_USERPROXY_LIFETIME);
		System.out.println("USERPROXY_LIFETIME = "+USERPROXY_LIFETIME);
	}
	public String getDefaultSAZUserTrusted(){
		return SAZ_USER_TRUSTED;
	}
	public String getDefaultSAZUserEnabled(){
                return SAZ_USER_ENABLED;
        }
        public String getDefaultSAZCATrusted(){
                return SAZ_CA_TRUSTED;
        }
        public String getDefaultSAZCAEnabled(){
                return SAZ_CA_ENABLED;
        }
        public String getDefaultSAZVOTrusted(){
                return SAZ_VO_TRUSTED;
        }
        public String getDefaultSAZVOEnabled(){
                return SAZ_VO_ENABLED;
        }
        public String getDefaultSAZRoleTrusted(){
                return SAZ_ROLE_TRUSTED;
        }
        public String getDefaultSAZRoleEnabled(){
                return SAZ_ROLE_ENABLED;
        }
	public String getDefaultSAZBanUserCertSerialNum(){
		return SAZ_BAN_USERCERT_SERIALNUM;
	}
	public String getDefaultSAZBanUserProxyLifetime(){
                return SAZ_BAN_USERPROXY_LIFETIME;
        }
	public String getDefaultUserProxyLifetime(){
                return USERPROXY_LIFETIME;
        }
}
